@@ -168,7 +168,8 @@ static void	 send_reg_cmds(const struct network_connect_context *)
 static void
 check_conn_fail()
 {
-	if (!g_on_air || (ssl_is_enabled() && net_ssl_begin() == -1))
+	if (!atomic_load_bool(&g_on_air) ||
+	    (ssl_is_enabled() && net_ssl_begin() == -1))
 		throw std::runtime_error(_("Failed to establish a connection"));
 }
 
@@ -238,7 +239,7 @@ establish_conn(struct addrinfo *res, PPRINTTEXT_CONTEXT ctx)
 		if (connect(g_socket, rp->ai_addr, rp->ai_addrlen) == 0) {
 			printtext(ctx, "%s", _("Connected!"));
 
-			g_on_air = true;
+			atomic_swap_bool(&g_on_air, true);
 
 			net_set_recv_timeout(DEFAULT_RECV_TIMEOUT);
 			net_set_send_timeout(DEFAULT_SEND_TIMEOUT);
@@ -316,7 +317,7 @@ handle_conn_err(PPRINTTEXT_CONTEXT ptext_ctx, const char *what,
 	ptext_ctx->spec_type = TYPE_SPEC1_FAILURE;
 	printtext(ptext_ctx, "%s", what);
 
-	g_on_air = false;
+	atomic_swap_bool(&g_on_air, false);
 
 	net_ssl_end();
 
@@ -670,7 +671,7 @@ icb(int &bytes_received, struct network_recv_context *ctx, char *recvbuf)
 
 	if (ret < 0 || static_cast<size_t>(ret) >= ARRAY_SIZE(array)) {
 		err_log(ENOBUFS, "%s", __func__);
-		g_connection_lost = true;
+		(void) atomic_swap_bool(&g_connection_lost, true);
 		return ERR;
 	}
 
@@ -678,7 +679,7 @@ icb(int &bytes_received, struct network_recv_context *ctx, char *recvbuf)
 	sw_assert(length >= 0 && length <= UCHAR_MAX);
 
 	if ((bytes_received = net_recv(ctx, recvbuf, length)) == -1) {
-		g_connection_lost = true;
+		(void) atomic_swap_bool(&g_connection_lost, true);
 	} else if (bytes_received != length && length != 0) {
 		const int	maxval = MAX(length, bytes_received);
 		const int	minval = MIN(length, bytes_received);
@@ -687,7 +688,7 @@ icb(int &bytes_received, struct network_recv_context *ctx, char *recvbuf)
 		if (get_and_handle_remaining_bytes(bytes_rem, ctx, recvbuf,
 		    length) == ERR) {
 			err_log(EPROTO, "%s", __func__);
-			g_connection_lost = true;
+			(void) atomic_swap_bool(&g_connection_lost, true);
 			return ERR;
 		}
 	} else if (bytes_received > 0) {
@@ -709,7 +710,7 @@ irc(int &bytes_received, struct network_recv_context *ctx, char *recvbuf,
     char **message_concat, enum message_concat_state *state)
 {
 	if ((bytes_received = net_recv(ctx, recvbuf, RECVBUF_SIZE)) == -1) {
-		g_connection_lost = true;
+		(void) atomic_swap_bool(&g_connection_lost, true);
 	} else if (bytes_received > 0) {
 		if (memchr(recvbuf, 0, bytes_received) != NULL)
 			destroy_null_bytes(recvbuf, bytes_received);
@@ -739,7 +740,8 @@ net_irc_listen(bool *connection_lost)
 		(void) atomic_swap_bool(&g_irc_listening, true);
 
 	block_signals();
-	*connection_lost = g_connection_lost = false;
+	*connection_lost = false;
+	atomic_swap_bool(&g_connection_lost, false);
 	recvbuf = static_cast<char *>(xmalloc(RECVBUF_SIZE + 1));
 	recvbuf[RECVBUF_SIZE] = '\0';
 	irc_init();
@@ -755,7 +757,8 @@ net_irc_listen(bool *connection_lost)
 
 			if ((bytes_received = net_recv(&ctx, recvbuf, 1)) ==
 			    -1) {
-				g_connection_lost = true;
+				(void) atomic_swap_bool(&g_connection_lost,
+				    true);
 				break;
 			} else if (bytes_received != 1) {
 				if (atomic_load_bool(&g_icb_processing_names))
@@ -774,17 +777,21 @@ net_irc_listen(bool *connection_lost)
 
 	  _conn_check:
 		if (bytes_received == 0 && should_check_connection()) {
-			if (conn_check() == -1)
-				g_connection_lost = true;
+			if (conn_check() == -1) {
+				(void) atomic_swap_bool(&g_connection_lost,
+				    true);
+			}
 		}
-	} while (g_on_air && !g_connection_lost);
+	} while (atomic_load_bool(&g_on_air) &&
+		 !atomic_load_bool(&g_connection_lost));
 
 	printtext_context_init(&ptext_ctx, g_active_window, TYPE_SPEC1_WARN,
 	    true);
-	*connection_lost = (g_on_air && g_connection_lost);
+	*connection_lost = (atomic_load_bool(&g_on_air) &&
+			    atomic_load_bool(&g_connection_lost));
 	if (*connection_lost)
 		printtext(&ptext_ctx, "%s", _("Connection to IRC server lost"));
-	g_on_air = false;
+	atomic_swap_bool(&g_on_air, false);
 	net_ssl_end();
 	if (g_socket != INVALID_SOCKET) {
 		CLOSE_GLOBAL_SOCKET();
@@ -804,8 +811,7 @@ net_irc_listen(bool *connection_lost)
 void
 net_kill_connection(void)
 {
-	g_disconnect_wanted = true;
-	g_connection_lost = g_on_air = false;
+	net_request_disconnect();
 
 	if (g_socket == INVALID_SOCKET)
 		return;
@@ -821,6 +827,14 @@ net_kill_connection(void)
 #endif
 }
 
+void
+net_request_disconnect(void)
+{
+	(void) atomic_swap_bool(&g_disconnect_wanted, true);
+	(void) atomic_swap_bool(&g_connection_lost, false);
+	(void) atomic_swap_bool(&g_on_air, false);
+}
+
 void
 server_destroy(struct server *server)
 {
