@@ -91,7 +91,7 @@ PIRC_WINDOW	g_active_window = NULL;
 PIRC_WINDOW	g_status_window = NULL;
 const char	g_status_window_label[10] = "(status)";
 const int	g_scroll_amount = 6;
-int		g_ntotal_windows = 0;
+_Atomic(int)	g_ntotal_windows = 0;
 volatile bool	g_redrawing_window = false;
 
 /* Objects with internal linkage
@@ -682,7 +682,9 @@ spawn_chat_window(CSTRING label, CSTRING title)
 	/*
 	 * send whois
 	 */
-	if (g_on_air && !is_irc_channel(entry->label) && !g_icb_mode)
+	if (atomic_load_bool(&g_on_air) &&
+	    !is_irc_channel(entry->label) &&
+	    !g_icb_mode)
 		cmd_whois(entry->label);
 
 	return 0;
